@@ -8,12 +8,12 @@ describe Virtus::Attribute, '#value_coerced?' do
   context 'when input is coerced' do
     let(:input)  { '1' }
 
-    it { should be(true) }
+    it { is_expected.to be(true) }
   end
 
   context 'when input is not coerced' do
     let(:input)  { 1 }
 
-    it { should be(false) }
+    it { is_expected.to be(false) }
   end
 end
